@@ -1,22 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2010 by Daniel Nicoletti                                *
- *   dantti12@gmail.com                                                    *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; see the file COPYING. If not, write to       *
- *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,  *
- *   Boston, MA 02110-1301, USA.                                           *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2010 Daniel Nicoletti <dantti12@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "AddPrinter.h"
 
@@ -34,7 +20,9 @@ Q_LOGGING_CATEGORY(PM_ADD_PRINTER, "pm.add.printer")
 
 int main(int argc, char **argv)
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+#endif
     AddPrinter app(argc, argv);
     app.setOrganizationDomain(QLatin1String("org.kde"));
 
