@@ -9,7 +9,9 @@
 
 #include <QSortFilterProxyModel>
 
-class Q_DECL_EXPORT JobSortFilterModel : public QSortFilterProxyModel
+#include <kcupslib_export.h>
+
+class KCUPSLIB_EXPORT JobSortFilterModel : public QSortFilterProxyModel
 {
     Q_OBJECT
     Q_PROPERTY(QString filteredPrinters READ filteredPrinters WRITE setFilteredPrinters NOTIFY filteredPrintersChanged)
