@@ -23,9 +23,4 @@ void ProcessRunner::openPrintQueue(const QString& printerName)
     QProcess::startDetached(QLatin1String("kde-print-queue"), {printerName});
 }
 
-void ProcessRunner::openPrintKCM()
-{
-    QProcess::startDetached(QLatin1String("kcmshell5"), {QLatin1String("kcm_printer_manager")});
-}
-
 #include "moc_ProcessRunner.cpp"
