@@ -29,22 +29,22 @@
 
 K_PLUGIN_CLASS_WITH_JSON(PrintKCM, "kcm_printer_manager.json")
 
+#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
+PrintKCM::PrintKCM(QObject *parent) :
+    KCModule(parent),
+#else
 PrintKCM::PrintKCM(QWidget *parent, const QVariantList &args) :
     KCModule(parent, args),
+#endif
     ui(new Ui::PrintKCM)
 {
-    auto aboutData = new KAboutData(QLatin1String("kcm_print"),
-                                    i18n("Print settings"),
-                                    QLatin1String(PM_VERSION),
-                                    i18n("Print settings"),
-                                    KAboutLicense::GPL,
-                                    i18n("(C) 2010-2018 Daniel Nicoletti"));
-    aboutData->addAuthor(QStringLiteral("Daniel Nicoletti"), QString(), QLatin1String("dantti12@gmail.com"));
-    aboutData->addAuthor(QStringLiteral("Jan Grulich"), i18n("Port to Qt 5 / Plasma 5"), QStringLiteral("jgrulich@redhat.com"));
-    setAboutData(aboutData);
     setButtons(NoAdditionalButton);
 
+#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
+    ui->setupUi(widget());
+#else
     ui->setupUi(this);
+#endif
 
     connect(ui->printerDesc, &PrinterDescription::updateNeeded, this, &PrintKCM::update);
 
@@ -52,7 +52,11 @@ PrintKCM::PrintKCM(QWidget *parent, const QVariantList &args) :
     // default dialog icon size is 32, this times 6 is 192 which is roughly the original width
     ui->printersTV->setMinimumWidth(192);
 
+#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
+    auto addMenu = new QMenu(widget());
+#else
     auto addMenu = new QMenu(this);
+#endif
     addMenu->addAction(i18nc("@action:intoolbar","Add a Printer Class"),
                        this, &PrintKCM::addClass);
     ui->addTB->setIcon(QIcon::fromTheme(QLatin1String("list-add")));
@@ -62,7 +66,12 @@ PrintKCM::PrintKCM(QWidget *parent, const QVariantList &args) :
     ui->removeTB->setIcon(QIcon::fromTheme(QLatin1String("list-remove")));
     ui->removeTB->setToolTip(i18n("Remove Printer"));
 
+#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
+    auto systemMenu = new QMenu(widget());
+#else
     auto systemMenu = new QMenu(this);
+#endif
+
     connect(systemMenu, &QMenu::triggered, this, &PrintKCM::systemPreferencesTriggered);
 #if CUPS_VERSION_MAJOR == 1 && CUPS_VERSION_MINOR < 6
     m_showSharedPrinters = systemMenu->addAction(i18nc("@action:intoolbar","Show printers shared by other systems"));
@@ -267,8 +276,12 @@ void PrintKCM::on_removeTB_clicked()
             msg = i18n("Are you sure you want to remove the printer '%1'?",
                        index.data(Qt::DisplayRole).toString());
         }
-        resp = KMessageBox::warningYesNo(this, msg, title);
-        if (resp == KMessageBox::Yes) {
+#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
+        resp = KMessageBox::warningTwoActions(widget(), msg, title, KStandardGuiItem::remove(), KStandardGuiItem::cancel());
+#else
+        resp = KMessageBox::warningTwoActions(this, msg, title, KStandardGuiItem::remove(), KStandardGuiItem::cancel());
+#endif
+        if (resp == KMessageBox::PrimaryAction) {
             QPointer<KCupsRequest> request = new KCupsRequest;
             request->deletePrinter(index.data(PrinterModel::DestName).toString());
             request->waitTillFinished();
@@ -305,7 +318,11 @@ void PrintKCM::getServerSettingsFinished(KCupsRequest *request)
 
     if (error) {
         if (request->property("interactive").toBool()) {
+#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
+            KMessageBox::detailedError(widget(),
+#else
             KMessageBox::detailedError(this,
+#endif
                                        i18nc("@info", "Failed to get server settings"),
                                        request->errorMsg(),
                                        i18nc("@title:window", "Failed"));
@@ -336,7 +353,11 @@ void PrintKCM::updateServerFinished(KCupsRequest *request)
             // Server is restarting, or auth was canceled, update the settings in one second
             QTimer::singleShot(1000, this, &PrintKCM::update);
         } else {
+#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
+            KMessageBox::detailedError(widget(),
+#else
             KMessageBox::detailedError(this,
+#endif
                                        i18nc("@info", "Failed to configure server settings"),
                                        request->errorMsg(),
                                        request->serverError());
